#
# spec file for package lilypond-doc
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without docbuild
%if 0%{?is_backports} && 0%{?sle_version} == 150200
#"%%_project" == "openSUSE:Backports:SLE-15-SP2:Update"
ExcludeArch:    x86 x86_64 aarch64 ppc64le s390x
%endif

%define ver     2.20
%define plevel  0
Name:           lilypond-doc
Version:        %{ver}.%{plevel}
Release:        lp152.2.5.10
Summary:        Documentation for the LilyPond Typesetter
License:        GFDL-1.3-only
Group:          Documentation/HTML
URL:            http://lilypond.org/
Source0:        lilypond-%{version}.tar.gz
%if %{without docbuild}
#Source1:        https://lilypond.org/download/binaries/documentation/lilypond-%%{version}-1.documentation.tar.bz2
%endif
# PATCH-FIX-UPSTREAM https://savannah.gnu.org/patch/index.php?9370
Patch0:         reproducible.patch
# Patches taken from Debian, see headers for info.
Patch1:         0101-read_relocation_dir-in-lilypond_datadir-too.patch
Patch2:         add_dircategories_to_documentation.patch
Patch3:         Issue-5243-1-editor-scm-Add-shell-quote-argument-function.diff
Patch4:         use_cstring_and_ctype_includes.patch
BuildRequires:  ImageMagick-extra
BuildRequires:  autoconf
BuildRequires:  bison
BuildRequires:  bitstream-vera-fonts
BuildRequires:  dblatex
BuildRequires:  dejavu
BuildRequires:  extractpdfmark
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  fontconfig-devel >= 2.4.0
BuildRequires:  fontforge
BuildRequires:  fonts-arabic
BuildRequires:  freetype2-devel >= 2.1.10
BuildRequires:  gcc-c++
BuildRequires:  gentium
BuildRequires:  gettext-tools
BuildRequires:  ghostscript >= 8.60
BuildRequires:  ghostscript-fonts-other
BuildRequires:  ghostscript-fonts-std
BuildRequires:  gzip
BuildRequires:  ifntjapa
BuildRequires:  liberation-fonts
BuildRequires:  libgnutls-devel
BuildRequires:  libtool
BuildRequires:  lilypond = %{version}
BuildRequires:  lndir
BuildRequires:  makeinfo >= 6.1
BuildRequires:  mc
BuildRequires:  mftrace
BuildRequires:  netpbm
BuildRequires:  pango-devel >= 1.6.0
BuildRequires:  perl
BuildRequires:  rsync
BuildRequires:  t1utils
BuildRequires:  texlive-avantgar-fonts
BuildRequires:  texlive-collection-fontsrecommended
BuildRequires:  texlive-dejavu-fonts
BuildRequires:  texlive-fancybox
BuildRequires:  texlive-gnu-freefont-fonts
BuildRequires:  texlive-lh
BuildRequires:  texlive-libertine-fonts
BuildRequires:  texlive-metafont-bin
BuildRequires:  texlive-metapost
BuildRequires:  texlive-xetex-bin
BuildRequires:  texlive-xltxtra
BuildRequires:  ttf-wqy-zenhei
BuildRequires:  xfntjp
BuildRequires:  xorg-x11-fonts
BuildRequires:  zip
BuildRequires:  pkgconfig(guile-1.8)
BuildRequires:  pkgconfig(python3)
Requires:       lilypond = %{version}
Requires(pre):   %{install_info_prereq} %{_bindir}/touch %{_bindir}/sed
Provides:       lilypond-documentation = %{version}
Obsoletes:      lilypond-documentation < %{version}
BuildArch:      noarch
%if %{with docbuild}
# NOTE: when lilypond documentation build with texinfo 5.x is fixed by upstream remove the 4s from makeinfo,
# NOTE: texinfo and update buildrequires with:
#BuildRequires: texi2html
BuildRequires:  texinfo4
%endif

%description
Common and english documentation files for the GNU LilyPond music typesetter.

%global rlversion %{version}
%define usrsrcp %{buildroot}
%define _configure ./smart-configure.sh

%package cs
Summary:        Documentation for the LilyPond Typesetter (cs)
Group:          Documentation/HTML
Requires:       %{name} = %{version}

%description cs
Czech documentation files for the GNU LilyPond music typesetter.

%package de
Summary:        Documentation for the LilyPond Typesetter (de)
Group:          Documentation/HTML
Requires:       %{name} = %{version}

%description de
German documentation files for the GNU LilyPond music typesetter.

%package es
Summary:        Documentation for the LilyPond Typesetter (es)
Group:          Documentation/HTML
Requires:       %{name} = %{version}

%description es
Spanish documentation files for the GNU LilyPond music typesetter.

%package fr
Summary:        Documentation for the LilyPond Typesetter (fr)
Group:          Documentation/HTML
Requires:       %{name} = %{version}

%description fr
French documentation files for the GNU LilyPond music typesetter.

%package hu
Summary:        Documentation for the LilyPond Typesetter (hu)
Group:          Documentation/HTML
Requires:       %{name} = %{version}

%description hu
Hungary documentation files for the GNU LilyPond music typesetter.

%package it
Summary:        Documentation for the LilyPond Typesetter (it)
Group:          Documentation/HTML
Requires:       %{name} = %{version}

%description it
Italian documentation files for the GNU LilyPond music typesetter.

%package ja
Summary:        Documentation for the LilyPond Typesetter (ja)
Group:          Documentation/HTML
Requires:       %{name} = %{version}

%description ja
Japanese documentation files for the GNU LilyPond music typesetter.

%package nl
Summary:        Documentation for the LilyPond Typesetter (nl)
Group:          Documentation/HTML
Requires:       %{name} = %{version}

%description nl
Dutch documentation files for the GNU LilyPond music typesetter.

%package zh
Summary:        Documentation for the LilyPond Typesetter (zh)
Group:          Documentation/HTML
Requires:       %{name} = %{version}

%description zh
Chinese documentation files for the GNU LilyPond music typesetter.

%prep
%setup -q -n lilypond-%{version}
%autopatch -p1

# Convert translations to UTF-8
for file in $(grep -L charset=UTF-8 po/*.po) ; do
    msgconv -t UTF-8 $file >$file.new
    mv $file.new $file
done
mkdir -p out/examples/
tar -cf - input/  | tar -C out/examples/ -xf- || true

%define _buildir $PWD
pushd scripts
for i in `grep -rl "/usr/bin/python"`;do sed -i '1s@^#!.*@#!/usr/bin/python3@' ${i} ;done
cd ../python
for i in `grep -rl "/usr/bin/python"`;do sed -i '1s@^#!.*@#!/usr/bin/python3@' ${i} ;done
popd
for i in `grep -rl "/usr/bin/env python"`;do sed -i '1s@^#!.*@#!/usr/bin/python3@' ${i} ;done

%build
mkdir -p $HOME/bin
export PATH=$HOME/bin:$PATH
echo $PATH
pushd $HOME/bin
for i in `ls -1 %{_bindir}/*texi*4`
do ln -sf ${i} $(basename --suffix 4 ${i})
done
popd
ls -l $HOME/bin

#chmod 644 Documentation/pictures/*.png
# export GS_LIB="/home/$USER/.fonts" is a work around for bnc#568280
export GS_LIB="$HOME/.fonts:%{_buildir}/mf/out"

export GUILE_AUTO_COMPILE=0
export CFLAGS="%{optflags} -ggdb -fpermissive -fabi-version=4"
export CXXFLAGS="$CFLAGS"
export LILYPOND_EXTERNAL_BINARY="%{_bindir}/lilypond"
export LILYPOND_BINARY=$LILYPOND_EXTERNAL_BINARY
rm configure
./smart-autogen.sh --noconfigure
%configure --with-ncsb-dir=%{_datadir}/ghostscript/fonts/
# build documentation
echo "*********************************"
echo "* Start the documentation build *"
echo "*********************************"
make -C scripts && make -C python
#pushd Documentation
# Don't build documentation in paralell. It fails randomly.
make -e doc LILYPOND_EXTERNAL_BINARY="%{_bindir}/lilypond" LILYPOND_BINARY=$LILYPOND_EXTERNAL_BINARY
#|| (cat out-www/suffix-lyxml.dblatex.log && false)
#|| (lndir  -ignorelinks out-www/notation . && \
#LILYPOND_EXTERNAL_BINARY="%%{_bindir}/lilypond" LILYPOND_BINARY=$LILYPOND_EXTERNAL_BINARY make doc)
#popd
#make -j1 out=www WWW-post

%install
mkdir -p "%{buildroot}%{_datadir}/lilypond/%{rlversion}"
# install documentation
make install-doc DESTDIR=%{buildroot} webdir=%{_docdir}/lilypond
cp -a DEDICATION HACKING ROADMAP AUTHORS.txt NEWS.txt \
  VERSION %{buildroot}%{_docdir}/lilypond

find %{buildroot}%{_docdir}/lilypond -name *.signature -exec rm {} \;
# Fix any .py files with shebangs and wrong permissions.
if test -z `find %{buildroot}%{_datadir}/lilypond/ -name *.py -perm 0644 -print0|xargs -0r grep -l '#!'`; \
then break;
else chmod -f 0755 `find %{buildroot}%{_datadir}/lilypond/ -name *.py -perm 0644 -print0|xargs -0r grep -l '#!'`; \
fi
LILYPOND_EXTERNAL_BINARY=%{_bindir}/lilypond
# Remove spurious executables rpm lint error
chmod 0644 %{buildroot}%{_docdir}/lilypond/Documentation/pictures/*png || true
%find_lang lilypond
texhash %{buildroot}%{_datadir}/lilypond/%{rlversion}
find %{buildroot}%{_docdir}/lilypond/ -type f -empty -delete -print
%fdupes -s %{buildroot}%{_docdir}
%fdupes -s %{buildroot}%{_datadir}/omf
%fdupes -s %{buildroot}%{_datadir}/locale
# remove info pages, they are part of lilypond package
rm %{buildroot}%{_infodir}/*
# create file lists for individual subpackages
for f in `find %{buildroot}/%{_datadir}`; do
  for l in cs de es fr hu it ja nl zh; do
    if [[ $f =~ \.$l\. ]]; then
      if [ -d $f ]; then
        f="%%dir $f"
      fi
      echo "$f" | sed "s:%{buildroot}/::" >> files-$l
      f=""
      break
    fi
  done

  if [ -z $f ]; then
    continue
  fi

  if [ -d $f ]; then
    f="%%dir $f"
  fi
  echo "$f" | sed "s:%{buildroot}/::" >> files-en
done
for d in '.usr.share' '.usr.share.doc' '.usr.share.info' '.usr.share.doc.packages'; do
  sed -i "/^%%dir $d$/d" files-en
done
for f in DEDICATION \
         HACKING ROADMAP VERSION AUTHORS.txt NEWS.txt; do
  echo "%%exclude %{_docdir}/lilypond/$f" >> files-en
done
echo "%%exclude %{_datadir}/lilypond/%{rlversion}/ls-R" >> files-en
#rm %%{_infodir}/lilypond || :

%post
ln -sf %{_docdir}/lilypond/Documentation %{_infodir}/lilypond && \
%install_info --debug --info-dir=%{_infodir} --info-file=%{_infodir}/lilypond.gz

%postun
rm -f %{_infodir}/lilypond

%files cs -f files-cs
%defattr(-,root,root)
%license LICENSE LICENSE.DOCUMENTATION COPYING

%files de -f files-de
%defattr(-,root,root)
%license LICENSE LICENSE.DOCUMENTATION COPYING

%files es -f files-es
%defattr(-,root,root)
%license LICENSE LICENSE.DOCUMENTATION COPYING

%files fr -f files-fr
%defattr(-,root,root)
%license LICENSE LICENSE.DOCUMENTATION COPYING

%files hu -f files-hu
%defattr(-,root,root)
%license LICENSE LICENSE.DOCUMENTATION COPYING

%files it -f files-it
%defattr(-,root,root)
%license LICENSE LICENSE.DOCUMENTATION COPYING

%files ja -f files-ja
%defattr(-,root,root)
%license LICENSE LICENSE.DOCUMENTATION COPYING

%files nl -f files-nl
%defattr(-,root,root)
%license LICENSE LICENSE.DOCUMENTATION COPYING

%files zh -f files-zh
%defattr(-,root,root)
%license LICENSE LICENSE.DOCUMENTATION COPYING

%files -f files-en
%defattr(-,root,root)
%license LICENSE LICENSE.DOCUMENTATION COPYING

%changelog
* Wed Aug 19 2020 Dave Plater <davejplater@gmail.com>
- Remove dependency on texinfo4-links package and generate the
  links in the spec file instead.
* Thu May  7 2020 Dave Plater <davejplater@gmail.com>
- Update to version 2.20.0.
- Removed incorporated and obsolete patches:
  Avoid-segfault-in-grob.cc-with-gcc-6.patch,
  Issue-5243-2-Let-get-editor-use-shell-quote-argument.diff,
  Issue-5243-3-More-conservative-parsing-of-textedit-URIs.diff,
  add_set-global-fonts_function.patch, hurd_file_name_support.patch,
  lilypond-doc-texinfo4.patch and  use_system_correctly.patch.
- lilypond-century-schoolbook-l-fonts replaced by
  lilypond-texgy-fonts.
- Lots of upstream new features and fixes, see:
  /usr/share/doc/packages/lilypond/NEWS.txt
* Mon Apr 20 2020 Antonio Larrosa <alarrosa@suse.com>
- Replace a BuildRequires: fontforge-devel with
  BuildRequires: fontforge, since the build system only requires
  the fontforge binary.
* Thu Mar 14 2019 normand@linux.vnet.ibm.com
- Add _constraints for PowerPC to avoid build error of lilypond-doc
* Fri Oct 12 2018 davejplater@gmail.com
- Fix Factory build by requiring missing fonts and texlive packages
  directly.
* Tue May 15 2018 davejplater@gmail.com
- Fix boo#1093056 CVE-2018-10992 with Debian patch.
  use_system_correctly.patch.
- Added 0101-read_relocation_dir-in-lilypond_datadir-too.patch
  hurd_file_name_support.patch
  Issue-5243-3-More-conservative-parsing-of-textedit-URIs.diff
  add_dircategories_to_documentation.patch
  Issue-5243-1-editor-scm-Add-shell-quote-argument-function.diff
  add_set-global-fonts_function.patch
  Issue-5243-2-Let-get-editor-use-shell-quote-argument.diff and
  use_cstring_and_ctype_includes.patch from Debian.
* Sun Mar  5 2017 rpm@fthiessen.de
- Some minor cleanup
* Fri Jul 17 2015 davejplater@gmail.com
- Created package texinfo4 from 13.2's texinfo package to fix the
  documentation build in Factory and future openSUSE versions
  until upstream have fixed the problem. See bnc#936870
- Added patch lilypond-doc-texinfo4.patch to enable lilypond to use
  the texinfo4 binaries to build the documentation.
* Wed Jul  1 2015 tjcw@physics.org
- Uncomment texi2html BuildRequires: to fix build break
  Note, the build can go for tens of minutes without producing any output.
  It will eventually make progress.
* Tue Feb 24 2015 dimstar@opensuse.org
- Add texi2html BuildRequires: this was split off from texinfo (as
  it's in fact an independent upstream tarball).
* Wed Dec 10 2014 pgajdos@suse.com
- split lilypond-doc [bnc#908078]
* Thu Nov 27 2014 dimstar@opensuse.org
- Don't build documentations in parallel. It breaks occasionally.
* Mon Mar 31 2014 pgajdos@suse.com
- updated to 2.18.2: This version provides a number of updates to
  2.18.0, including updated manuals.  We recommend all users to
  upgrade to this version.
* Thu Jan  2 2014 pgajdos@suse.com
- updated to 2.18.0:
  * final release, see changelogs for beta versions
- dropped use-recommended-freetype-include.patch (upstreamed)
* Wed Dec 18 2013 pgajdos@suse.com
- updated to 2.17.97:
  * beta phase to 2.18
  * bugfixes
* Tue Nov 26 2013 pgajdos@suse.com
-  updated to 2.17.96:
  * beta phase to 2.18
  * bugfixes
* Mon Sep  9 2013 pgajdos@suse.com
- updated to 2.17.26:
  * Decimal numbers can now be written directly in music, without a
    hash sign.  Together with the previous change in the way object
    properties are specified, the code to change the length of stems
    has changed from this:
    \override Stem #'length = #5.6
    e' f' g' a'
    to this:
    \override Stem.length = 5.6
    e' f' g' a'
    One has to write a digit on both sides of the dot - values like
    `4.' or `-.3' are not allowed.
    Decimal fractions are also not accepted in `\chordmode'.
  * A number of shorthands like `(', `)', `|', `[', `]', `~', `\(',
    `\)' and others can now freely be redefined like normal commands.
    An example would be
    "\\{" = (
    "\\}" = )
    "(" = \melisma
    ")" = \melismaEnd
    \new Staff <<
    \relative c' {
    c8 \{ d e f \} %% slurred
    g ( a b c ) %% no slur, but with melisma
    c,1 \bar "|."
    }
    \addlyrics { Li -- ly -- pond. }
    >>
    [image of music]
  * The articulation shorthand for `\staccatissimo' has been renamed
    from `-|' to `-!'.
  * Tempo change ranges are now written as `\tempo 4 = 60 - 68' rather
    than `\tempo 4 = 60 ~ 68'.
- make-doc-crash.patch upstreamed
* Tue Aug 13 2013 pgajdos@suse.com
- updated to 2.17.24:
  * bugfixes
- make doc do not crash anymore
  + lilypond-make-doc-crash.patch
* Tue Aug  6 2013 pgajdos@suse.com
- updated to 2.17.23:
  * bugfixes
- removed python26.patch and gcc44-relocate.patch
* Wed Mar 27 2013 pgajdos@suse.com
- updated to 2.17.14:
  * The meaning of `instrumentTransposition' has been reversed.  After
    \set instrumentTransposition = #{ b #}
    a written `c'' now sounds like `b'.  Previously, this would have
    been the other way round.  This and the following change should
    make dealing with transposing instruments more straightforward.
  * The music generated by `\set' and `\override' commands is no
    longer affected by `\transpose'.  The main consequence is that
    `\transpose' will transpose audible/concert pitch and printed
    pitch by the same amount even when the transposed music contains
    `\transposition'.  Previously,
    \transpose c' f' \transposition bes'
    was equivalent to `\transposition f''.  Now it stays equivalent to
    `\transposition bes''.
  * Tuplets are now created with the `\tuplet' command, which takes a
    fraction `T/N' to specify that T notes are played in the time
    usually allowed for N. One `\tuplet' command can create several
    tuplet groups if their duration is typed after the fraction.
    \tuplet 3/2 { c8 d e } \tuplet 3/2 { f e d } c2
    \tuplet 3/2 4 { c8 d e f e d } c2
    [image of music]
    The `\times' command with its inverted fraction order `N/T' is
    still available.
  etc. see NEWS.txt
* Mon Dec 31 2012 pgajdos@suse.com
- updated to version 2.17.9:
  * The `\clef' command supports optional octavation:
    \clef "treble_(8)"
    c2 c
    \clef "bass^[15]"
    c2 c
  * The LilyPond syntax of dot-separated words `Voice.Accidental' has
    been made interchangeable with `#'(Voice Accidental)', a Scheme
    list of symbols.  As one result, code like
    \override Voice.TextSpanner #'(bound-details left text) = "rit."
    is now equivalent to
    \override Voice.TextSpanner bound-details.left.text = "rit."
    or even
    \override #'(Voice TextSpanner) bound-details.left.text = "rit."
  * Grob and grob property path no longer need to be specified as two
    separate arguments to commands like `\override' and `\revert',
    allowing for the syntax
    \override Voice.TextSpanner.bound-details.left.text = "rit."
    Since complementary music functions like `\overrideProperty'
    cannot support forms with and without separating space at the same
    time, using a single dotted path is now the preferred form.
    Specifying grob path and grob property path separately, currently
    still supported with `\override' and `\revert' for compatibility
    reasons, is deprecated.
  * Due to words now being accepted as symbol function arguments, the
    interfaces of `\accidentalStyle', `\alterBroken', `\footnote' and
    `\tweak' had to be redesigned where optional symbol arguments were
    involved.  Please check the respective music function
    documentation for details.
  * Several commands now accept symbol lists (conveniently entered as
    dot-separated words) for various kinds of arguments.  These
    include `\accidentalStyle', `\alterBroken', `\footnote', `\hide',
    `\omit', `\overrideProperty', `\shape', and `\tweak'.
  * The bar line user interface has changed. Bar glyphs now resemble
    the appearance of the bar line, so a left repeat sign has to be
    coded as `.|:'. The command `\defineBarLine' provides an easy way
    to define additional bar line styles.
  * Accidentals in the key signature may be printed in octaves other
    than their traditional positions, or in multiple octaves.
* Thu Dec 20 2012 dmueller@suse.com
- remove unnecessary (and conflicting) buildrequires on libicu
* Mon Nov 19 2012 j.mairboeck@gmail.com
- update to version 2.16.1
- This is a bugfix update see :
  http://code.google.com/p/lilypond/issues/list?can=1&q=Fixed_2_16_1
* Wed Aug 29 2012 j.mairboeck@gmail.com
- Remove dependency on ghostscript-fonts-rus (not available on >= 12.2).
* Wed Aug 29 2012 j.mairboeck@gmail.com
- Readd lilypond-doc for 2.16.0
* Sat Mar 17 2012 davejplater@gmail.com
- Split off lilypond-doc to a separate package.
